pub struct User {
user_id: OnceCell<OwnedUserId>,
user_id_string: PhantomData<String>,
session: OnceCell<Session>,
is_own_user: Cell<bool>,
pub(super) has_display_name: Cell<bool>,
is_verified: Cell<bool>,
is_ignored: Cell<bool>,
ignored_handler: RefCell<Option<SignalHandlerId>>,
}Fields
user_id: OnceCell<OwnedUserId>The ID of this user.
user_id_string: PhantomData<String>The ID of this user, as a string.
session: OnceCell<Session>The current session.
is_own_user: Cell<bool>Whether this user is the same as the session’s user.
has_display_name: Cell<bool>Whether this user has a display name set.
If the display name is not set, the display-name property returns
the localpart of the user ID.
is_verified: Cell<bool>Whether this user has been verified.
is_ignored: Cell<bool>Whether this user is currently ignored.
ignored_handler: RefCell<Option<SignalHandlerId>>Implementations
Sourceimpl User
impl User
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl User
impl User
Sourcepub(super) fn user_id(&self) -> &OwnedUserId
pub(super) fn user_id(&self) -> &OwnedUserId
The ID of this user.
Sourcefn user_id_string(&self) -> String
fn user_id_string(&self) -> String
The ID of this user, as a string.
Sourcepub(crate) fn set_user_id(&self, user_id: OwnedUserId)
pub(crate) fn set_user_id(&self, user_id: OwnedUserId)
Set the ID of this user.
Sourcepub(super) fn set_has_display_name(&self, has_display_name: bool)
pub(super) fn set_has_display_name(&self, has_display_name: bool)
Set whether this user has a display name set.
Sourcepub(super) async fn local_crypto_identity(&self) -> Option<UserIdentity>
pub(super) async fn local_crypto_identity(&self) -> Option<UserIdentity>
Get the local cryptographic identity (aka cross-signing identity) of this user.
Locally, we should always have the crypto identity of our own user and of users with whom we share an encrypted room.
Sourceasync fn init_is_verified(&self)
async fn init_is_verified(&self)
Load whether this user is verified.
Sourcepub(super) async fn create_direct_chat(&self) -> Result<Room, Error>
pub(super) async fn create_direct_chat(&self) -> Result<Room, Error>
Create an encrypted direct chat with this user.